{
  lib,
  pkgs,
  ...
}:

{
  imports = [
    ./hardware-configuration.nix
    ./gitea-runner.nix
    ./nix-serve.nix
    ../desktop.nix
  ];

  nixpkgs = {
    hostPlatform = "x86_64-linux";
    config = {
      nvidia.acceptLicense = true;
    };
  };

  boot.loader = {
    systemd-boot = {
      enable = true;
      graceful = true;
      netbootxyz.enable = true;
    };
    efi.canTouchEfiVariables = true;
  };

  networking = {
    hostId = "c5e68d78";
    networkmanager.enable = true;
    firewall.trustedInterfaces = [
      "lxdbr0"
      "virbr0"
    ]; # Work around https://github.com/NixOS/nixpkgs/issues/263359
  };

  virtualisation = {
    libvirtd.enable = true;
    lxd.enable = true;
  };

  services.sunshine = {
    enable = true;
    package = pkgs.unstable.sunshine;
    capSysAdmin = true;
  };

  modules = {
    hardware.presonus-studio.enable = true;
    services = {
      borgmatic = {
        enable = true;
        directories = [
          "/home/jordan/Documents"
          "/home/jordan/Downloads"
          "/home/jordan/Music"
          "/home/jordan/Pictures"
          "/home/jordan/projects"
          "/home/jordan/Videos"
          "/home/jordan/.mozilla"
        ];
        repoPath = "ssh://iqwu22oq@iqwu22oq.repo.borgbase.com/./repo";
      };
    };
    system.desktop = {
      gnome.enable = lib.mkForce false;
      hyprland.enable = true;
    };
  };

  system.stateVersion = "22.11";
}
